@@ -1,3 +1,3 @@
 # flake8: noqa: F401
-from .if_oadhm import OffAxisHologram
+from .if_oah import OffAxisHologram
 from .if_qlsi import QLSInterferogram
