@@ -1,7 +1,11 @@
+import atexit
 import shutil
 import tempfile
 import time
 
+import qpretrieve
+
+
 TMPDIR = tempfile.mkdtemp(prefix=time.strftime(
     "qpretrieve_test_%H.%M_"))
 
@@ -13,10 +17,8 @@ def pytest_configure(config):
     file after command line options have been parsed.
     """
     tempfile.tempdir = TMPDIR
-
-
-def pytest_unconfigure(config):
-    """
-    called before test process is exited.
-    """
-    shutil.rmtree(TMPDIR, ignore_errors=True)
+    atexit.register(shutil.rmtree, TMPDIR, ignore_errors=True)
+    # This will make the tests pass faster, because we are not
+    # creating FFTW wisdom. Also, it makes the tests more reproducible
+    # by sticking to simple numpy FFTs.
+    qpretrieve.fourier.PREFERRED_INTERFACE = "FFTFilterNumpy"
